@@ -7,6 +7,8 @@ class MethodName(str, enum.Enum):
     CANCEL_ORDER = "private/cancel-order"
     CLOSE_POSITION = "private/close-position"
     CREATE_ORDER = "private/create-order"
+    CREATE_WITHDRAWAL = "private/create-withdrawal"
+    GET_CURRENCY_NETWORKS = "private/get-currency-networks"
     GET_DEPOSIT_ADDRESS = "private/get-deposit-address"
     GET_OPEN_ORDERS = "private/get-open-orders"
     GET_POSITIONS = "private/get-positions"
