@@ -1,5 +1,5 @@
 from .order import OrderType, OrderStatus, OrderSide, Order, OrderDict
-from .response_message import CryptodotcomResponseMessage
+from .response_message import CryptodotcomResponseMessage, HttpResponse
 from .request import CryptodotcomRequestMessage
 from .enhanced_websocket import EnhancedWebsocket, EnhancedWebsocketBehaviorSubject
 from .user_balance import UserBalance, PositionBalance
@@ -15,6 +15,8 @@ from .framework import BookConfig, CryptodotcomContext
 from .status import Status
 from .message_types import MessageTypes
 from .bundle import WebsocketBundle, WebsocketMessageBundle, WebsocketStatusBundle
+from .currency_networks import Network, NetworkDetails, NetworkResponse
+from .withdrawal import CreateWithdrawalResponse
 
 __all__ = [
     "BookConfig",
@@ -23,7 +25,11 @@ __all__ = [
     "CryptodotcomResponseMessage",
     "EnhancedWebsocket",
     "EnhancedWebsocketBehaviorSubject",
+    "HttpResponse",
     "MessageTypes",
+    "Network", 
+    "NetworkDetails", 
+    "NetworkResponse",
     "Order",
     "OrderbookDict",
     "OrderbookEntryNamedTuple",
@@ -41,4 +47,5 @@ __all__ = [
     "WebsocketBundle",
     "WebsocketMessageBundle",
     "WebsocketStatusBundle",
+    "CreateWithdrawalResponse",
 ]
