@@ -8,7 +8,7 @@ from reactivex.observable import ConnectableObservable
 from reactivex.disposable import CompositeDisposable
 from reactivex.scheduler import ThreadPoolScheduler
 
-from .response_message import CryptodotcomResponseMessage
+from .response_message import CryptodotcomResponseMessage, HttpResponse
 from .enhanced_websocket import EnhancedWebsocket, EnhancedWebsocketBehaviorSubject
 from .bundle import WebsocketBundle
 from .user_balance import (
@@ -16,7 +16,8 @@ from .user_balance import (
 )
 from .trade import Trade
 from .order import OrderDict
-from .rest import OrderCreateRequest
+from .rest import OrderCreateRequest, CreateWithdrawalRequest
+from .currency_networks import NetworkResponse
 
 
 class BookConfig(NamedTuple):
@@ -43,8 +44,10 @@ class CryptodotcomContext:
         [OrderCreateRequest],
         Observable[OrderDict],
     ]
+    create_withdrawal_http: Callable[[CreateWithdrawalRequest], Observable[HttpResponse]]
     exchange: cryptocom
     feed_messages: Observable[CryptodotcomResponseMessage]
+    get_currency_networks_http: Callable[[], Observable[HttpResponse]]
     get_user_trades: Callable[[str, int], Observable[list[Trade]]]
     get_user_trades_http: Callable[[str, int], Observable[list[Trade]]]
     get_user_balance: Callable[[], Observable[list[UserBalance]]]
