@@ -1,5 +1,5 @@
 import dataclasses
-from typing import Any
+from typing import Any, TypedDict
 
 
 @dataclasses.dataclass
@@ -11,3 +11,10 @@ class CryptodotcomResponseMessage:
     message: str = ""
     original: str = ""
     channel: str = ""
+
+
+class HttpResponse(TypedDict):
+    id: int
+    method: str
+    code: int
+    result: Any
